@@ -3,17 +3,13 @@
 module Main where
 
 ------------------------------------------------------------------------------
-import           Test.Framework                 (defaultMain, testGroup, Test)
+import           Test.Hspec
 import           Data.Map.Syntax.Tests
 
 
-------------------------------------------------------------------------------
-tests :: [Test]
-tests = [testGroup "Simple insertion testing" insTests
-        ,testGroup "Monoid laws" monoidLaws
-        ,testGroup "Nested block insertion testing" nestingTests]
-
-
 ------------------------------------------------------------------------------
 main :: IO ()
-main = defaultMain tests
+main = hspec $ do
+  describe "simple insertions" insTests
+  describe "monoid laws" monoidLaws
+  describe "nested block insertions" nestingTests
